import { Ref, forwardRef, memo, useImperativeHandle, useRef, useState } from "react";

interface Props {
	addressType: 'home'|'hotel'
	differentDropOff: boolean
}

export interface ForwardRef {
	showModal: ()=>void
}

export default memo(forwardRef(function Step2Confirmation({addressType, differentDropOff}: Props, ref: Ref<ForwardRef>){
	const dialogRef = useRef<HTMLDialogElement|null>(null);
	const [homeAddressType, setHomeAddressType] = useState<'home'|'office'|'hotel'>();
	const [collectionType, setCollectionType] = useState<'use_reception'|'from_outside'|'meet_driver'>();

	function showModal(){ dialogRef.current?.showModal(); }
	function closeModal(){ dialogRef.current?.close(); }

	useImperativeHandle(ref, ()=>({showModal}));

	return (
		<dialog ref={dialogRef} className="modal duration-0">
			<div className="modal-box max-w-[650px] text-brand-black">
				<div className="text-2xl">
					<h1 className="font-bold">Confirm your address for pickup & delivery</h1>
					<p className="mt-2.5 text-brand-black/50">720 seneca st seattle 98101</p>
				</div>
				{
					addressType==='home' ? 
					<div>
						<h2 className="text-2xl mt-6 font-bold">Choose address type</h2>
						<div className="grid grid-cols-3 gap-x-6 mt-2.5">
							<button onClick={()=>{setHomeAddressType('home')}} className={`btn flex items-center gap-x-3 bg-transparent rounded-md border-brand-black hover:border-2 hover:border-brand-blue hover:bg-[#F5F9FD] ${homeAddressType==='home' && 'border-2 border-brand-blue bg-[#F5F9FD]'}`}>
								<img src="https://ik.imagekit.io/choreless/v2/icons/FigmaHome.svg" alt="icon" loading="lazy" />
								<p className="text-xl font-normal">Home</p>
							</button>
							<button onClick={()=>{setHomeAddressType('office')}} className={`btn flex items-center gap-x-3 bg-transparent rounded-md border-brand-black hover:border-2 hover:border-brand-blue hover:bg-[#F5F9FD] ${homeAddressType==='office' && 'border-2 border-brand-blue bg-[#F5F9FD]'}`}>
								<img src="https://ik.imagekit.io/choreless/v2/icons/FigmaShop.svg" alt="icon" loading="lazy" />
								<p className="text-xl font-normal">Office</p>
							</button>
							<button onClick={()=>{setHomeAddressType('hotel')}} className={`btn flex items-center gap-x-3 bg-transparent rounded-md border-brand-black hover:border-2 hover:border-brand-blue hover:bg-[#F5F9FD] ${homeAddressType==='hotel' && 'border-2 border-brand-blue bg-[#F5F9FD]'}`}>
								<img src="https://ik.imagekit.io/choreless/v2/icons/FigmaGirl.svg" alt="icon" loading="lazy" />
								<p className="text-xl font-normal">Hotel</p>
							</button>
						</div>
						<div>
							<label className="input-float mt-5">
								<input type="text" placeholder="" />
								<p>Name this place (optional)</p>
							</label>
							<label className="input-float mt-5">
								<input type="text" placeholder="" />
								<p>Add home details ( apartment name, number, floor,...)</p>
							</label>
						</div>
					</div> :
					<div>
						<div className="grid grid-cols-[auto_1fr] gap-x-5 mt-5">
							<img src="https://ik.imagekit.io/choreless/v2/images/signup/FigmaHotel" alt="hotel" loading='lazy' className="w-[250px] h-[250px] rounded-md" />
							<img src="https://ik.imagekit.io/choreless/v2/images/signup/FigmaMap" alt="map" loading='lazy' className="h-full rounded-md object-cover" />
						</div>
						<label className="input-float mt-5">
							<input type="text" placeholder="" />
							<p>Enter your room number</p>
						</label>
					</div>
				}
				<h2 className="text-brand-black text-2xl font-bold mt-5">Select collection type</h2>
				<div className={`grid gap-x-6 mt-2.5 min-h-[8.25rem] ${(addressType==='home' && homeAddressType==='home') ? 'grid-cols-3' : 'grid-cols-2' }`}>
					<button onClick={()=>{setCollectionType('use_reception')}} className={`btn h-auto flex flex-col items-center gap-x-3 bg-transparent rounded-md border-brand-black hover:border-2 hover:border-brand-blue hover:bg-[#F5F9FD] ${collectionType==='use_reception' && 'border-2 border-brand-blue bg-[#F5F9FD]'}`}>
						<img src="https://ik.imagekit.io/choreless/v2/icons/FigmaAlarm.svg" alt="icon" loading="lazy" />
						<p className="text-xl font-normal">Use reception</p>
					</button>
					{
						addressType==='home' && homeAddressType==='home' &&
						<button onClick={()=>{setCollectionType('from_outside')}} className={`btn h-auto flex flex-col items-center gap-x-3 bg-transparent rounded-md border-brand-black hover:border-2 hover:border-brand-blue hover:bg-[#F5F9FD] ${collectionType==='from_outside' && 'border-2 border-brand-blue bg-[#F5F9FD]'}`}>
							<img src="https://ik.imagekit.io/choreless/v2/icons/FigmaDoor.svg" alt="icon" loading="lazy" />
							<p className="text-xl font-normal">From outside</p>
						</button>
					}
					<button onClick={()=>{setCollectionType('meet_driver')}} className={`btn h-auto flex flex-col items-center gap-x-3 bg-transparent rounded-md border-brand-black hover:border-2 hover:border-brand-blue hover:bg-[#F5F9FD] ${collectionType==='meet_driver' && 'border-2 border-brand-blue bg-[#F5F9FD]'}`}>
						<img src="https://ik.imagekit.io/choreless/v2/icons/FigmaMan.svg" alt="icon" loading="lazy" />
						<p className="text-xl font-normal">Meet driver</p>
					</button>
				</div>
				<div>
					<label className="cursor-pointer flex items-center gap-x-3 mt-5">
						<input type="checkbox" className="checkbox checkbox-primary w-5 h-5" />
						<div className="text-black">Message me on arrival</div>
					</label>
					{
						addressType==='home' && homeAddressType==='office' &&
						<label className="cursor-pointer flex items-center gap-x-3 mt-5">
							<input type="checkbox" className="checkbox checkbox-primary w-5 h-5" />
							<div className="text-black">Leave it at my door if i’m not home</div>
						</label>
					}
				</div>
				<button className="btn w-full h-[3.75rem] rounded-[0.3125rem] text-lg mt-[1.6875rem] px-5 py-[0.9375rem] text-white bg-brand-orange border-brand-orange hover:text-brand-orange hover:bg-transparent hover:border-brand-orange">Save and Continue</button>
			</div>
			<div className="modal-backdrop bg-black/40" onClick={closeModal} />
		</dialog>
	)
}))
